@@ -41,7 +41,7 @@ use Try::Tiny;
 use Path::Class qw/file dir/;
 use Module::Runtime;
 
-use RapidApp::Include qw(sugar perlutil);
+use RapidApp::Util qw(:all);
 
 # This is ugly/temporary -- mechanism to pull in additional configs from the
 # RapidDbic helper trait. Currently this is only exposed in rdbic.pl (--crud-profile)
@@ -206,6 +206,32 @@ sub _get_source_list {
   return sort ($schema->sources);
 }
 
+# This is the cleanest way to munge the arguments passed to make_schema_at (in parent)
+# to inject our custom loader_class option. 
+#  -- See Catalyst::Helper::Model::DBIC::Schema::_gen_static_schema to understand why
+around '_gen_static_schema' => sub {
+  my ($orig,$self,@args) = @_;
+
+  my $connect_info = $self->connect_info;
+  my $loader_args  = $self->loader_args;
+  my $metakeys = $self->_ra_rapiddbic_opts->{metakeys};
+
+  no warnings 'redefine';
+
+  local *connect_info = sub {
+    $connect_info, { loader_class => 'RapidApp::Util::MetaKeys::Loader' }
+  };
+
+  local *loader_args = sub {
+    $metakeys
+      ? { %$loader_args, metakeys => $metakeys }
+      : $loader_args
+  };
+
+  $self->$orig(@args)
+};
+
+
 
 1;
 
